#
# spec file for package subtitlecomposer
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           subtitlecomposer
Version:        0.6.6
Release:        lp150.1.6
Summary:        A text-based subtitle editor
License:        GPL-2.0+
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://github.com/maxrd2/subtitlecomposer/
Source0:        https://github.com/maxrd2/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.10
BuildRequires:  extra-cmake-modules
BuildRequires:  kauth-devel
BuildRequires:  kcodecs-devel
BuildRequires:  kconfig-devel
BuildRequires:  kconfigwidgets-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  ki18n-devel
BuildRequires:  kio-devel
BuildRequires:  kross-devel
BuildRequires:  ktextwidgets-devel
BuildRequires:  kwidgetsaddons-devel
BuildRequires:  kxmlgui-devel
BuildRequires:  pkgconfig
BuildRequires:  sonnet-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.6
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libxine)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mpv)
BuildRequires:  pkgconfig(phonon4qt5)
Recommends:     %{name}-lang = %{version}
%if 0%{?suse_version} < 1500
Requires(post): shared-mime-info
Requires(postun): shared-mime-info
%endif

%description
A text-based subtitles editor that supports basic operations. It supports
SubRip (SRT), MicroDVD, SSA/ASS, MPlayer, TMPlayer and YouTube captions, and
has speech Recognition using PocketSphinx.

%lang_package

%prep
%setup -q

# Fix permissions
chmod 644 ChangeLog

# Fix shebang
sed -i '1s|/usr/bin/env python|%{__python}|' \
       src/scripting/examples/*.py
sed -i '1s|/usr/bin/env ruby|%{_bindir}/ruby|' \
       src/scripting/examples/*.rb

%build
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build

# Fix persissions
chmod 755 %{buildroot}%{_kf5_appsdir}/%{name}/scripts/*.py
chmod 755 %{buildroot}%{_kf5_appsdir}/%{name}/scripts/*.rb
# Fix rpmlint error (devel-file-in-non-devel-package) and install header files as doc (since they are installed just for help)
mkdir files_for_doc
cp -a %{buildroot}%{_kf5_appsdir}/%{name}/scripts/api/ files_for_doc/
rm -rf %{buildroot}%{_kf5_appsdir}/%{name}/scripts/api/
# Point to the correct path of the header files directory (doc)
perl -pi -e "s|'api'|'/usr/share/doc/packages/subtitlecomposer/api'|" %{buildroot}%{_kf5_appsdir}/%{name}/scripts/README

%suse_update_desktop_file -r %{name} Qt KDE AudioVideo AudioVideoEditing

%find_lang %{name}

%{kf5_post_install}

%if 0%{?suse_version} < 1500
%post
%mime_database_post

%postun
%mime_database_postun
%endif

%files
%doc AUTHORS ChangeLog README.md TODO files_for_doc/api
%license COPYING
%{_kf5_applicationsdir}/%{name}.desktop
%{_kf5_appsdir}/%{name}/
%{_kf5_bindir}/%{name}
%config(noreplace) %{_kf5_configdir}/%{name}rc
%dir %{_kf5_iconsdir}/hicolor/256x256
%dir %{_kf5_iconsdir}/hicolor/256x256/apps
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_kxmlguidir}/%{name}/
%{_kf5_libdir}/%{name}/
%{_datadir}/mime/packages/%{name}.xml

%files lang -f %{name}.lang

%changelog
* Sun Feb 11 2018 aloisio@gmx.com
- Update to version 0.6.6
  * Fixed open video dialog filters
  * Fixed "Insert Line" on waveform adding at the wrong index -
    thanks @qsniyg
  * Added MMB seeking on waveform - thanks @qsniyg
  * Fixed some compilation issues
  * Updated translations - thanks @gogogogi, @muzena
  * Fixed vobsub when opening from video file and symbol cache
    filename
  * Fixed subtitle loading times of huge files
  * Improved vobsub text detection
  * Fixed ASS rich text parsing on import subtitle stream action
  * Replaced buggy mplayer vobsub import code with ffmpeg
  * Fixed memory leaks/usage of WaveformWidget's scroll animation
  * Optimized import subtitle stream from video action
  * Replaced gstreamer with ffmpeg libraries in application core
    usage
  * Added abort button to speech recognition
  * Waveform smooth scrolling
  * Added join/split lines actions to waveform context menu
  * Fixed some crashes, memory leaks and overall code cleanups
  * Cleaned up settings widget and texts
- Dropped subtitlecomposer-Qt56.patch (merged upstream)
- Spec cleanup
* Fri Nov  3 2017 aloisio@gmx.com
- Update to version 0.6.5
  add:
  * Added support for binary subtitle formats
  * fine control video playback speed
  * controls for video playback speed
  mod:
  * GStreamer backend audio improvements.
  * Moved open video actions under File menu
  * More tolerant parsing of SubRip subtitles.
  * Improved split lines command
  * Updated Czech translation - thanks @goliashcz
  * Updated Croatian translations - thanks @muzena
  fix:
  * Waveform widget dragging and speed improvements, fixed
    buffer overflow
  * WaveformWidget: zoom out wasn't working on movies without
    audio
  * Fixed cases where subtitle hide time would end up before
    show time.
  * Improved context menus.
  * Fixed moving of anchored lines.
  * Open subtitle wouldn't autoload video in some cases
  * Open video now includes .divx and .webm extensions
  * Tools menu scripts are filtered based on installed kross
    interpreters
  * Moved custom icons to more standard location, using
    QIcon::fromTheme()
  * Error Check > Absolute Duration config fields were changing
    incorrect values.
  * MPV Backend: fixed deprecated options, updated vo devices -
    thanks @luzfcb
  * better rendering on high DPI screens.
  * MPV Backend: framerate/video length  wasn't reported to
    subtitle composer anymore
  * detection/handling of current playing line
  * Parsing text containing <font> without color attribute
  * compilation without xine - thanks @pinotree
  * ASS parsing - thanks @Martchus
- Added subtitlecomposer-Qt56.patch to be able to build against
  Qt 5.6 on Leap
* Tue Jun 13 2017 jengelh@inai.de
- Reword vague description.
* Mon Oct 31 2016 asterios.dramis@gmail.com
- Update directories not owned by package to cover also
  Factory/Tumbleweed.
* Thu Jun 23 2016 asterios.dramis@gmail.com
- Update to 0.6.4:
  * ADD: WaveformWidget: context menu
  * MOD: Updated German translations - thanks @Martchus
  * MOD: Updated Croatian translations - thanks @muzena
  * FIX: Inserting subtitle line would corrupt subtitle indexes
  * FIX: Display audio of WebM/FLV files in waveform - thanks
    @Martchus
  From 0.6.3:
  * ADD: WaveformWidget: customization settings page
  * ADD: Speech recognition with PocketSphinx
  * MOD: Waveform and Player widgets can be docked to any side of
    the main window
  * MOD: WaveformWidget: can be manually scrolled even if
    autoscroll is enabled
  * MOD: WaveformWidget: ability to drag whole subtitle line
  * MOD: Updated croatian translation - thanks @muzena
  * FIX: Video player fullscreen and icon display under was not
    right under some desktop environments - thanks @Martchus
  * FIX: WaveformWidget: when dragging subtitle borders (or
    clicking near them), show/hide time was jumping to mouse
    position
  * FIX: po/Messages.sh will generate .po files compatible with Qt
    Linguist, and will run from any path
  * FIX: Build cleanups - thanks @pinotree
  From 0.6.2:
  * ADD: Ability to demux text streams from loaded video
  * MOD: WaveformWidget: added scrollbar and manual scrolling mode,
    improved zoom, widget state is loaded/saved
  * MOD: WaveformWidget: double click will seek in video player
  * MOD: WaveformWidget: subtitle show/hide time can be dragged
  * MOD: Added default shortcut for play/pause video.
  * MOD: Support for building with cmake older version than 3.3
  * FIX: Changing player backend setting will reopen loaded video
    in new player backend.
  * FIX: Timeline after last anchored subtitle was scaled
    incorrectly.
  * FIX: WaveformWidget: optimizations and speed improvements
  * FIX: Recent files list was not saved properly in some cases
    (subtitle list full).
  * FIX: WaveformWidget: fixed crash after closing subtitle
  * FIX: WaveformWidget: editing of non-anchored lines is not
    allowed
  * FIX: StreamProcessor was not freeing it's resources.
  * FIX: Updated configure and install scripts
  * FIX: Removed "Decoder backend" entry from video player settings
    page.
  From 0.6.1:
  * FIX: Anchor points syncing wasn't working right in some cases
  From 0.6.0:
  * ADD: Anchor points syncing
  * ADD: Waveform widget.
  * MOD: Improved precision of the Time class.
  * MOD: GStreamerPlayerBackend will pause when reaching
    end-of-stream instead of stopping/resetting player.
  * MOD: Converted playerbackends to plugins
  * MOD: updated German translation
  * FIX: Video player widget will repaint background correctly.
  * FIX: Code refactoring, cleanups and optimizations.
  * FIX: fixed/enabled Drag & Drop
  From 0.5.9:
  * FIX: Improved error reporting during video open.
  * MOD: Added italian translation.
  From 0.5.8:
  * ADD: MPV player support
  * MOD: Replaced remaining KDE4 deprecated code, removed
    KDELibs4Support dependency. Finalized KF5 porting.
  * MOD: Update croatian translation and README.md
  * MOD: Added option not to resume playback after subtitle
    doubleclick if player is paused
  * FIX: Gettext translations were not created during build
    process.
  * FIX: FindGStreamer.cmake was not searching for and including
    arch-specific include dir
  * FIX: Errors/Spelling in "Error Check" settings
  * FIX: Build process fixes
  * FIX: improved player/decoder backends, solved crashes when
    switching backends
  * FIX: Added option to antialias subtitles
  * FIX: Phonon player backend was displaying embeded subtitles
  * FIX: OBS (OpenSuse) package creation was failing
- Updated build/runtime requirements to KF5/Qt5.
- Added new build requirement mpv-devel.
- Removed fdupes macro (not needed anymore).
- Removed NULL-pointer.patch and
  Find-platform-dependant-include-files-of-GStreamer.patch (fixed
  upstream).
* Sun Jan  3 2016 asterios.dramis@gmail.com
- Added Find-platform-dependant-include-files-of-GStreamer.patch in
  order to fix finding of platform-dependant include files of
  GStreamer (fixes compilation failure).
* Sun Nov 16 2014 hrvoje.senjan@gmail.com
- Update to 0.5.7
  * GStreamer 1.0 API support
- Switch BuildRequires to reflect above change
- Added NULL-pointer.patch from upstream, to resolve post-buid-check
  failure
* Wed Dec  4 2013 asterios.dramis@gmail.com
- Update to 0.5.6
  [#] Continuation of original package since initial author stopped development
  * SubStation Alpha format fixes and color support
  * source cleanup
  From 0.5.5:
  * text color support
  * SubRip text color support
  * reworked MicroDVD open/save
  From 0.5.4:
  * mplayer2 support
  * mplayer VDPAU decoding support
  * minor cmake build fixes
- Added libicu-devel build requirement.
- Removed all previous patches (fixed upstream).
* Sun Jan 29 2012 asterios.dramis@gmail.com
- Updated no-copy-dt-needed-entries.patch to fix a new linking error with
  libX11.
* Mon Dec  5 2011 asterios.dramis@gmail.com
- Added a patch (no-copy-dt-needed-entries.patch) to fix linking with
  - -no-copy-dt-needed-entries.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to GPL-2.0+ (SPDX style).
* Thu Jun  2 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Recommend instead of Suggest the subtitlecomposer-lang package.
  * Added update-mime-database in %%post/%%postun scripts for the mime file
    installed by the package.
  * Minor other updates.
* Tue Jan 18 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Added a subtitlecomposer-lang package.
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Buildrequires:, %%prep and %%install sections.
  * Fixed rpmlint warnings (devel-file-in-non-devel-package,
    non-executable-script).
  * Fixed rpm post build check about directories not owned by a package.
- Add a patch to fix installation of python scripting examples.
* Thu Jun 24 2010 cmorve69@yahoo.es
- Fix compilation with GCC 4.5
* Sat Jul  4 2009 cmorve69@yahoo.es
- First version
